Module: Aws::PrometheusService::Types

Defined in:
lib/aws-sdk-prometheusservice/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AlertManagerDefinitionDescription, AlertManagerDefinitionStatus, AmpConfiguration, AnomalyDetectorConfiguration, AnomalyDetectorDescription, AnomalyDetectorMissingDataAction, AnomalyDetectorStatus, AnomalyDetectorSummary, CloudWatchConfiguration, CloudWatchLogDestination, ComponentConfig, ConflictException, CreateAlertManagerDefinitionRequest, CreateAlertManagerDefinitionResponse, CreateAnomalyDetectorRequest, CreateAnomalyDetectorResponse, CreateLoggingConfigurationRequest, CreateLoggingConfigurationResponse, CreateQueryLoggingConfigurationRequest, CreateQueryLoggingConfigurationResponse, CreateRuleGroupsNamespaceRequest, CreateRuleGroupsNamespaceResponse, CreateScraperRequest, CreateScraperResponse, CreateWorkspaceRequest, CreateWorkspaceResponse, DeleteAlertManagerDefinitionRequest, DeleteAnomalyDetectorRequest, DeleteLoggingConfigurationRequest, DeleteQueryLoggingConfigurationRequest, DeleteResourcePolicyRequest, DeleteRuleGroupsNamespaceRequest, DeleteScraperLoggingConfigurationRequest, DeleteScraperRequest, DeleteScraperResponse, DeleteWorkspaceRequest, DescribeAlertManagerDefinitionRequest, DescribeAlertManagerDefinitionResponse, DescribeAnomalyDetectorRequest, DescribeAnomalyDetectorResponse, DescribeLoggingConfigurationRequest, DescribeLoggingConfigurationResponse, DescribeQueryLoggingConfigurationRequest, DescribeQueryLoggingConfigurationResponse, DescribeResourcePolicyRequest, DescribeResourcePolicyResponse, DescribeRuleGroupsNamespaceRequest, DescribeRuleGroupsNamespaceResponse, DescribeScraperLoggingConfigurationRequest, DescribeScraperLoggingConfigurationResponse, DescribeScraperRequest, DescribeScraperResponse, DescribeWorkspaceConfigurationRequest, DescribeWorkspaceConfigurationResponse, DescribeWorkspaceRequest, DescribeWorkspaceResponse, Destination, EksConfiguration, GetDefaultScraperConfigurationRequest, GetDefaultScraperConfigurationResponse, IgnoreNearExpected, InternalServerException, LimitsPerLabelSet, LimitsPerLabelSetEntry, ListAnomalyDetectorsRequest, ListAnomalyDetectorsResponse, ListRuleGroupsNamespacesRequest, ListRuleGroupsNamespacesResponse, ListScrapersRequest, ListScrapersResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListWorkspacesRequest, ListWorkspacesResponse, LoggingConfigurationMetadata, LoggingConfigurationStatus, LoggingDestination, LoggingFilter, PutAlertManagerDefinitionRequest, PutAlertManagerDefinitionResponse, PutAnomalyDetectorRequest, PutAnomalyDetectorResponse, PutResourcePolicyRequest, PutResourcePolicyResponse, PutRuleGroupsNamespaceRequest, PutRuleGroupsNamespaceResponse, QueryLoggingConfigurationMetadata, QueryLoggingConfigurationStatus, RandomCutForestConfiguration, ResourceNotFoundException, RoleConfiguration, RuleGroupsNamespaceDescription, RuleGroupsNamespaceStatus, RuleGroupsNamespaceSummary, ScrapeConfiguration, ScraperComponent, ScraperDescription, ScraperLoggingConfigurationStatus, ScraperLoggingDestination, ScraperStatus, ScraperSummary, ServiceQuotaExceededException, Source, TagResourceRequest, TagResourceResponse, ThrottlingException, UntagResourceRequest, UntagResourceResponse, UpdateLoggingConfigurationRequest, UpdateLoggingConfigurationResponse, UpdateQueryLoggingConfigurationRequest, UpdateQueryLoggingConfigurationResponse, UpdateScraperLoggingConfigurationRequest, UpdateScraperLoggingConfigurationResponse, UpdateScraperRequest, UpdateScraperResponse, UpdateWorkspaceAliasRequest, UpdateWorkspaceConfigurationRequest, UpdateWorkspaceConfigurationResponse, ValidationException, ValidationExceptionField, VpcConfiguration, WorkspaceConfigurationDescription, WorkspaceConfigurationStatus, WorkspaceDescription, WorkspaceStatus, WorkspaceSummary

Instance Attribute Summary collapse

Instance Attribute Details

#amountFloat

The absolute amount by which values can differ from expected values before being considered anomalous.

Returns:

  • (Float)


1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1477

class IgnoreNearExpected < Struct.new(
  :amount,
  :ratio,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Amount < IgnoreNearExpected; end
  class Ratio < IgnoreNearExpected; end
  class Unknown < IgnoreNearExpected; end
end

#amp_configurationTypes::AmpConfiguration

The Amazon Managed Service for Prometheus workspace to send metrics to.



1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1391

class Destination < Struct.new(
  :amp_configuration,
  :cloud_watch_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AmpConfiguration < Destination; end
  class CloudWatchConfiguration < Destination; end
  class Unknown < Destination; end
end

#cloud_watch_configurationTypes::CloudWatchConfiguration

The CloudWatch dataset to send metrics to.



1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1391

class Destination < Struct.new(
  :amp_configuration,
  :cloud_watch_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AmpConfiguration < Destination; end
  class CloudWatchConfiguration < Destination; end
  class Unknown < Destination; end
end

#cloud_watch_logsTypes::CloudWatchLogDestination

The CloudWatch Logs configuration for the scraper logging destination.



2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2626

class ScraperLoggingDestination < Struct.new(
  :cloud_watch_logs,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CloudWatchLogs < ScraperLoggingDestination; end
  class Unknown < ScraperLoggingDestination; end
end

#configuration_blobString

The base 64 encoded scrape configuration file.

Returns:

  • (String)


2476
2477
2478
2479
2480
2481
2482
2483
2484
2485
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2476

class ScrapeConfiguration < Struct.new(
  :configuration_blob,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ConfigurationBlob < ScrapeConfiguration; end
  class Unknown < ScrapeConfiguration; end
end

#eks_configurationTypes::EksConfiguration

The Amazon EKS cluster from which a scraper collects metrics.



2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2781

class Source < Struct.new(
  :eks_configuration,
  :vpc_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EksConfiguration < Source; end
  class VpcConfiguration < Source; end
  class Unknown < Source; end
end

#mark_as_anomalyBoolean

Marks missing data points as anomalies.

Returns:

  • (Boolean)


207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/aws-sdk-prometheusservice/types.rb', line 207

class AnomalyDetectorMissingDataAction < Struct.new(
  :mark_as_anomaly,
  :skip,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MarkAsAnomaly < AnomalyDetectorMissingDataAction; end
  class Skip < AnomalyDetectorMissingDataAction; end
  class Unknown < AnomalyDetectorMissingDataAction; end
end

#random_cut_forestTypes::RandomCutForestConfiguration

The Random Cut Forest algorithm configuration for anomaly detection.



113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-prometheusservice/types.rb', line 113

class AnomalyDetectorConfiguration < Struct.new(
  :random_cut_forest,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RandomCutForest < AnomalyDetectorConfiguration; end
  class Unknown < AnomalyDetectorConfiguration; end
end

#ratioFloat

The ratio by which values can differ from expected values before being considered anomalous.

Returns:

  • (Float)


1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1477

class IgnoreNearExpected < Struct.new(
  :amount,
  :ratio,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Amount < IgnoreNearExpected; end
  class Ratio < IgnoreNearExpected; end
  class Unknown < IgnoreNearExpected; end
end

#skipBoolean

Skips evaluation when data is missing.

Returns:

  • (Boolean)


207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/aws-sdk-prometheusservice/types.rb', line 207

class AnomalyDetectorMissingDataAction < Struct.new(
  :mark_as_anomaly,
  :skip,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MarkAsAnomaly < AnomalyDetectorMissingDataAction; end
  class Skip < AnomalyDetectorMissingDataAction; end
  class Unknown < AnomalyDetectorMissingDataAction; end
end

#vpc_configurationTypes::VpcConfiguration

The Amazon VPC configuration for the Prometheus collector when connecting to Amazon MSK clusters. This configuration enables secure, private network connectivity between the collector and your Amazon MSK cluster within your Amazon VPC.



2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2781

class Source < Struct.new(
  :eks_configuration,
  :vpc_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EksConfiguration < Source; end
  class VpcConfiguration < Source; end
  class Unknown < Source; end
end