Class: Aws::PrometheusService::Types::AnomalyDetectorMissingDataAction

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Note:

AnomalyDetectorMissingDataAction is a union - when making an API calls you must set exactly one of the members.

Note:

AnomalyDetectorMissingDataAction is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AnomalyDetectorMissingDataAction corresponding to the set member.

Specifies the action to take when data is missing during anomaly detection evaluation.

Defined Under Namespace

Classes: MarkAsAnomaly, Skip, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#mark_as_anomalyBoolean

Marks missing data points as anomalies.

Returns:

  • (Boolean)


207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/aws-sdk-prometheusservice/types.rb', line 207

class AnomalyDetectorMissingDataAction < Struct.new(
  :mark_as_anomaly,
  :skip,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MarkAsAnomaly < AnomalyDetectorMissingDataAction; end
  class Skip < AnomalyDetectorMissingDataAction; end
  class Unknown < AnomalyDetectorMissingDataAction; end
end

#skipBoolean

Skips evaluation when data is missing.

Returns:

  • (Boolean)


207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/aws-sdk-prometheusservice/types.rb', line 207

class AnomalyDetectorMissingDataAction < Struct.new(
  :mark_as_anomaly,
  :skip,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MarkAsAnomaly < AnomalyDetectorMissingDataAction; end
  class Skip < AnomalyDetectorMissingDataAction; end
  class Unknown < AnomalyDetectorMissingDataAction; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



207
208
209
# File 'lib/aws-sdk-prometheusservice/types.rb', line 207

def unknown
  @unknown
end