Class: Aws::PrometheusService::Types::CloudWatchLogDestination

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Configuration details for logging to CloudWatch Logs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_arnString

The ARN of the CloudWatch log group to which the vended log data will be published. This log group must exist prior to calling this operation.

Returns:

  • (String)


310
311
312
313
314
# File 'lib/aws-sdk-prometheusservice/types.rb', line 310

class CloudWatchLogDestination < Struct.new(
  :log_group_arn)
  SENSITIVE = []
  include Aws::Structure
end