Class: Aws::PrometheusService::Types::CreateScraperRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::CreateScraperRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Represents the input of a CreateScraper operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
(optional) An alias to associate with the scraper.
-
#client_token ⇒ String
(Optional) A unique, case-sensitive identifier that you can provide to ensure the idempotency of the request.
-
#destination ⇒ Types::Destination
The destination where the scraper sends the collected metrics.
-
#exporters ⇒ Array<Types::ExporterConfiguration>
The exporter configurations for the scraper.
-
#role_configuration ⇒ Types::RoleConfiguration
Use this structure to enable cross-account access, so that you can use a target account to access Prometheus metrics from source accounts.
-
#scrape_configuration ⇒ Types::ScrapeConfiguration
The configuration file to use in the new scraper.
-
#source ⇒ Types::Source
The Amazon EKS or Amazon Web Services cluster from which the scraper will collect metrics.
-
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values to associate with the scraper.
Instance Attribute Details
#alias ⇒ String
(optional) An alias to associate with the scraper. This is for your use, and does not need to be unique.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
(Optional) A unique, case-sensitive identifier that you can provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The destination where the scraper sends the collected metrics. Valid destinations are Amazon Managed Service for Prometheus workspaces and CloudWatch datasets.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |
#exporters ⇒ Array<Types::ExporterConfiguration>
The exporter configurations for the scraper. You can configure at most one Amazon OpenSearch Service domain. If you don't specify a value, the scraper is created without an exporter configuration.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |
#role_configuration ⇒ Types::RoleConfiguration
Use this structure to enable cross-account access, so that you can use a target account to access Prometheus metrics from source accounts.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |
#scrape_configuration ⇒ Types::ScrapeConfiguration
The configuration file to use in the new scraper. For more information, see Scraper configuration in the Amazon Managed Service for Prometheus User Guide.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::Source
The Amazon EKS or Amazon Web Services cluster from which the scraper will collect metrics.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values to associate with the scraper.
706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 706 class CreateScraperRequest < Struct.new( :alias, :scrape_configuration, :source, :destination, :role_configuration, :client_token, :tags, :exporters) SENSITIVE = [] include Aws::Structure end |