Class: Aws::PrometheusService::Types::CreateWorkspaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Represents the input of a CreateWorkspace operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

An alias that you assign to this workspace to help you identify it. It does not need to be unique.

Blank spaces at the beginning or end of the alias that you specify will be trimmed from the value used.

Returns:

  • (String)


777
778
779
780
781
782
783
784
# File 'lib/aws-sdk-prometheusservice/types.rb', line 777

class CreateWorkspaceRequest < Struct.new(
  :alias,
  :client_token,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique identifier that you can provide to ensure the idempotency of the request. Case-sensitive.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


777
778
779
780
781
782
783
784
# File 'lib/aws-sdk-prometheusservice/types.rb', line 777

class CreateWorkspaceRequest < Struct.new(
  :alias,
  :client_token,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

(optional) The ARN for a customer managed KMS key to use for encrypting data within your workspace. For more information about using your own key in your workspace, see Encryption at rest in the Amazon Managed Service for Prometheus User Guide.

Returns:

  • (String)


777
778
779
780
781
782
783
784
# File 'lib/aws-sdk-prometheusservice/types.rb', line 777

class CreateWorkspaceRequest < Struct.new(
  :alias,
  :client_token,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The list of tag keys and values to associate with the workspace.

Returns:

  • (Hash<String,String>)


777
778
779
780
781
782
783
784
# File 'lib/aws-sdk-prometheusservice/types.rb', line 777

class CreateWorkspaceRequest < Struct.new(
  :alias,
  :client_token,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end