Class: Aws::PrometheusService::Types::DescribeAnomalyDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::DescribeAnomalyDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_id ⇒ String
The identifier of the anomaly detector to describe.
-
#workspace_id ⇒ String
The identifier of the workspace containing the anomaly detector.
Instance Attribute Details
#anomaly_detector_id ⇒ String
The identifier of the anomaly detector to describe.
1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1101 class DescribeAnomalyDetectorRequest < Struct.new( :workspace_id, :anomaly_detector_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The identifier of the workspace containing the anomaly detector.
1101 1102 1103 1104 1105 1106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1101 class DescribeAnomalyDetectorRequest < Struct.new( :workspace_id, :anomaly_detector_id) SENSITIVE = [] include Aws::Structure end |