Class: Aws::PrometheusService::Types::DescribeQueryLoggingConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::DescribeQueryLoggingConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#query_logging_configuration ⇒ Types::QueryLoggingConfigurationMetadata
The detailed information about the query logging configuration for the specified workspace.
Instance Attribute Details
#query_logging_configuration ⇒ Types::QueryLoggingConfigurationMetadata
The detailed information about the query logging configuration for the specified workspace.
1176 1177 1178 1179 1180 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1176 class DescribeQueryLoggingConfigurationResponse < Struct.new( :query_logging_configuration) SENSITIVE = [] include Aws::Structure end |