Class: Aws::PrometheusService::Types::IgnoreNearExpected

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Note:

IgnoreNearExpected is a union - when making an API calls you must set exactly one of the members.

Note:

IgnoreNearExpected is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of IgnoreNearExpected corresponding to the set member.

Configuration for threshold settings that determine when values near expected values should be ignored during anomaly detection.

Defined Under Namespace

Classes: Amount, Ratio, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amountFloat

The absolute amount by which values can differ from expected values before being considered anomalous.

Returns:

  • (Float)


1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1453

class IgnoreNearExpected < Struct.new(
  :amount,
  :ratio,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Amount < IgnoreNearExpected; end
  class Ratio < IgnoreNearExpected; end
  class Unknown < IgnoreNearExpected; end
end

#ratioFloat

The ratio by which values can differ from expected values before being considered anomalous.

Returns:

  • (Float)


1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1453

class IgnoreNearExpected < Struct.new(
  :amount,
  :ratio,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Amount < IgnoreNearExpected; end
  class Ratio < IgnoreNearExpected; end
  class Unknown < IgnoreNearExpected; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1453
1454
1455
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1453

def unknown
  @unknown
end