Class: Aws::PrometheusService::Types::ListRuleGroupsNamespacesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::ListRuleGroupsNamespacesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Represents the output of a ListRuleGroupsNamespaces operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token indicating that there are more results to retrieve.
-
#rule_groups_namespaces ⇒ Array<Types::RuleGroupsNamespaceSummary>
The returned list of rule groups namespaces.
Instance Attribute Details
#next_token ⇒ String
A token indicating that there are more results to retrieve. You can
use this token as part of your next ListRuleGroupsNamespaces
request to retrieve those results.
1691 1692 1693 1694 1695 1696 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1691 class ListRuleGroupsNamespacesResponse < Struct.new( :rule_groups_namespaces, :next_token) SENSITIVE = [] include Aws::Structure end |
#rule_groups_namespaces ⇒ Array<Types::RuleGroupsNamespaceSummary>
The returned list of rule groups namespaces.
1691 1692 1693 1694 1695 1696 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1691 class ListRuleGroupsNamespacesResponse < Struct.new( :rule_groups_namespaces, :next_token) SENSITIVE = [] include Aws::Structure end |