Class: Aws::PrometheusService::Types::ListScrapersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::ListScrapersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Represents the input of a ListScrapers operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Hash<String,Array<String>>
(Optional) A list of key-value pairs to filter the list of scrapers returned.
-
#max_results ⇒ Integer
Optional) The maximum number of scrapers to return in one
ListScrapersoperation. -
#next_token ⇒ String
(Optional) The token for the next set of items to return.
Instance Attribute Details
#filters ⇒ Hash<String,Array<String>>
(Optional) A list of key-value pairs to filter the list of scrapers
returned. Keys include status, sourceArn, destinationArn, and
alias.
Filters on the same key are OR'd together, and filters on
different keys are AND'd together. For example,
status=ACTIVE&status=CREATING&alias=Test, will return all scrapers
that have the alias Test, and are either in status ACTIVE or
CREATING.
To find all active scrapers that are sending metrics to a specific Amazon Managed Service for Prometheus workspace, you would use the ARN of the workspace in a query:
status=ACTIVE&destinationArn=arn:aws:aps:us-east-1:123456789012:workspace/ws-example1-1234-abcd-56ef-123456789012
If this is included, it filters the results to only the scrapers that match the filter.
1735 1736 1737 1738 1739 1740 1741 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1735 class ListScrapersRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Optional) The maximum number of scrapers to return in one
ListScrapers operation. The range is 1-1000.
If you omit this parameter, the default of 100 is used.
1735 1736 1737 1738 1739 1740 1741 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1735 class ListScrapersRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Optional) The token for the next set of items to return. (You received this token from a previous call.)
1735 1736 1737 1738 1739 1740 1741 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1735 class ListScrapersRequest < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |