Class: Aws::PrometheusService::Types::ListScrapersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Represents the output of a ListScrapers operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token indicating that there are more results to retrieve. You can use this token as part of your next ListScrapers operation to retrieve those results.

Returns:

  • (String)


1758
1759
1760
1761
1762
1763
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1758

class ListScrapersResponse < Struct.new(
  :scrapers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scrapersArray<Types::ScraperSummary>

A list of ScraperSummary structures giving information about scrapers in the account that match the filters provided.

Returns:



1758
1759
1760
1761
1762
1763
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1758

class ListScrapersResponse < Struct.new(
  :scrapers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end