Class: Aws::PrometheusService::Types::PutAlertManagerDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::PutAlertManagerDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Represents the output of a PutAlertManagerDefinition operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ Types::AlertManagerDefinitionStatus
A structure that returns the current status of the alert manager definition.
Instance Attribute Details
#status ⇒ Types::AlertManagerDefinitionStatus
A structure that returns the current status of the alert manager definition.
2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2011 class PutAlertManagerDefinitionResponse < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |