Class: Aws::PrometheusService::Types::RandomCutForestConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Configuration for the Random Cut Forest algorithm used for anomaly detection in time-series data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ignore_near_expected_from_aboveTypes::IgnoreNearExpected

Configuration for ignoring values that are near expected values from above during anomaly detection.



2323
2324
2325
2326
2327
2328
2329
2330
2331
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2323

class RandomCutForestConfiguration < Struct.new(
  :query,
  :shingle_size,
  :sample_size,
  :ignore_near_expected_from_above,
  :ignore_near_expected_from_below)
  SENSITIVE = []
  include Aws::Structure
end

#ignore_near_expected_from_belowTypes::IgnoreNearExpected

Configuration for ignoring values that are near expected values from below during anomaly detection.



2323
2324
2325
2326
2327
2328
2329
2330
2331
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2323

class RandomCutForestConfiguration < Struct.new(
  :query,
  :shingle_size,
  :sample_size,
  :ignore_near_expected_from_above,
  :ignore_near_expected_from_below)
  SENSITIVE = []
  include Aws::Structure
end

#queryString

The Prometheus query used to retrieve the time-series data for anomaly detection.

Random Cut Forest queries must be wrapped by a supported PromQL aggregation operator. For more information, see Aggregation operators on the Prometheus docs website.

Supported PromQL aggregation operators: avg, count, group, max, min, quantile, stddev, stdvar, and sum.



2323
2324
2325
2326
2327
2328
2329
2330
2331
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2323

class RandomCutForestConfiguration < Struct.new(
  :query,
  :shingle_size,
  :sample_size,
  :ignore_near_expected_from_above,
  :ignore_near_expected_from_below)
  SENSITIVE = []
  include Aws::Structure
end

#sample_sizeInteger

The number of data points sampled from the input stream for the Random Cut Forest algorithm. The default number is 256 consecutive data points.



2323
2324
2325
2326
2327
2328
2329
2330
2331
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2323

class RandomCutForestConfiguration < Struct.new(
  :query,
  :shingle_size,
  :sample_size,
  :ignore_near_expected_from_above,
  :ignore_near_expected_from_below)
  SENSITIVE = []
  include Aws::Structure
end

#shingle_sizeInteger

The number of consecutive data points used to create a shingle for the Random Cut Forest algorithm. The default number is 8 consecutive data points.



2323
2324
2325
2326
2327
2328
2329
2330
2331
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2323

class RandomCutForestConfiguration < Struct.new(
  :query,
  :shingle_size,
  :sample_size,
  :ignore_near_expected_from_above,
  :ignore_near_expected_from_below)
  SENSITIVE = []
  include Aws::Structure
end