Class: Aws::PrometheusService::Types::ScraperDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::ScraperDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
The ScraperDescription structure contains the full details about one
scraper in your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
(Optional) A name associated with the scraper.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the scraper.
-
#created_at ⇒ Time
The date and time that the scraper was created.
-
#destination ⇒ Types::Destination
The destination where the scraper sends metrics.
-
#exporters ⇒ Array<Types::ExporterConfiguration>
The exporter configurations for the scraper, if configured.
-
#last_modified_at ⇒ Time
The date and time that the scraper was last modified.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the scraper to discover and collect metrics on your behalf.
-
#role_configuration ⇒ Types::RoleConfiguration
This structure displays information about the IAM roles used for cross-account scraping configuration.
-
#scrape_configuration ⇒ Types::ScrapeConfiguration
The configuration in use by the scraper.
-
#scraper_id ⇒ String
The ID of the scraper.
-
#source ⇒ Types::Source
The Amazon EKS cluster from which the scraper collects metrics.
-
#status ⇒ Types::ScraperStatus
A structure that contains the current status of the scraper.
-
#status_reason ⇒ String
If there is a failure, the reason for the failure.
-
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values associated with the scraper.
Instance Attribute Details
#alias ⇒ String
(Optional) A name associated with the scraper.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the scraper. For example,
arn:aws:aps:<region>:123456798012:scraper/s-example1-1234-abcd-5678-ef9012abcd34.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the scraper was created.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The destination where the scraper sends metrics. Valid destinations are Amazon Managed Service for Prometheus workspaces and CloudWatch datasets.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#exporters ⇒ Array<Types::ExporterConfiguration>
The exporter configurations for the scraper, if configured. The list contains at most one configuration for an Amazon OpenSearch Service domain.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#last_modified_at ⇒ Time
The date and time that the scraper was last modified.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the scraper to discover and collect metrics on your behalf.
For example,
arn:aws:iam::123456789012:role/service-role/AmazonGrafanaServiceRole-12example.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#role_configuration ⇒ Types::RoleConfiguration
This structure displays information about the IAM roles used for cross-account scraping configuration.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#scrape_configuration ⇒ Types::ScrapeConfiguration
The configuration in use by the scraper.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#scraper_id ⇒ String
The ID of the scraper. For example,
s-example1-1234-abcd-5678-ef9012abcd34.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::Source
The Amazon EKS cluster from which the scraper collects metrics.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ScraperStatus
A structure that contains the current status of the scraper.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
If there is a failure, the reason for the failure.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values associated with the scraper.
2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2628 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration, :exporters) SENSITIVE = [] include Aws::Structure end |