Class: Aws::PrometheusService::Types::ScraperSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::ScraperSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
The ScraperSummary structure contains a summary of the details about
one scraper in your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
(Optional) A name associated with the scraper.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the scraper.
-
#created_at ⇒ Time
The date and time that the scraper was created.
-
#destination ⇒ Types::Destination
The destination where the scraper sends metrics.
-
#last_modified_at ⇒ Time
The date and time that the scraper was last modified.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the scraper to discover and collect metrics on your behalf.
-
#role_configuration ⇒ Types::RoleConfiguration
This structure displays information about the IAM roles used for cross-account scraping configuration.
-
#scraper_id ⇒ String
The ID of the scraper.
-
#source ⇒ Types::Source
The Amazon EKS cluster from which the scraper collects metrics.
-
#status ⇒ Types::ScraperStatus
A structure that contains the current status of the scraper.
-
#status_reason ⇒ String
If there is a failure, the reason for the failure.
-
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values associated with the scraper.
Instance Attribute Details
#alias ⇒ String
(Optional) A name associated with the scraper.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the scraper.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the scraper was created.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The destination where the scraper sends metrics. Valid destinations are Amazon Managed Service for Prometheus workspaces and CloudWatch datasets.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_at ⇒ Time
The date and time that the scraper was last modified.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the scraper to discover and collect metrics on your behalf.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#role_configuration ⇒ Types::RoleConfiguration
This structure displays information about the IAM roles used for cross-account scraping configuration.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#scraper_id ⇒ String
The ID of the scraper.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::Source
The Amazon EKS cluster from which the scraper collects metrics.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ScraperStatus
A structure that contains the current status of the scraper.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
If there is a failure, the reason for the failure.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values associated with the scraper.
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2711 class ScraperSummary < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |