Class: Aws::PrometheusService::Types::Source

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Note:

Source is a union - when making an API calls you must set exactly one of the members.

Note:

Source is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Source corresponding to the set member.

The source of collected metrics for a scraper.

Defined Under Namespace

Classes: EksConfiguration, Unknown, VpcConfiguration

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eks_configurationTypes::EksConfiguration

The Amazon EKS cluster from which a scraper collects metrics.



2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2842

class Source < Struct.new(
  :eks_configuration,
  :vpc_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EksConfiguration < Source; end
  class VpcConfiguration < Source; end
  class Unknown < Source; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2842
2843
2844
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2842

def unknown
  @unknown
end

#vpc_configurationTypes::VpcConfiguration

The Amazon VPC configuration for the Prometheus collector when connecting to Amazon MSK clusters. This configuration enables secure, private network connectivity between the collector and your Amazon MSK cluster within your Amazon VPC.



2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2842

class Source < Struct.new(
  :eks_configuration,
  :vpc_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EksConfiguration < Source; end
  class VpcConfiguration < Source; end
  class Unknown < Source; end
end