Class: Aws::PrometheusService::Types::UpdateScraperLoggingConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::UpdateScraperLoggingConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#logging_destination ⇒ Types::ScraperLoggingDestination
The destination where scraper logs will be sent.
-
#scraper_components ⇒ Array<Types::ScraperComponent>
The list of scraper components to configure for logging.
-
#scraper_id ⇒ String
The ID of the scraper whose logging configuration will be updated.
Instance Attribute Details
#logging_destination ⇒ Types::ScraperLoggingDestination
The destination where scraper logs will be sent.
3026 3027 3028 3029 3030 3031 3032 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3026 class UpdateScraperLoggingConfigurationRequest < Struct.new( :scraper_id, :logging_destination, :scraper_components) SENSITIVE = [] include Aws::Structure end |
#scraper_components ⇒ Array<Types::ScraperComponent>
The list of scraper components to configure for logging.
3026 3027 3028 3029 3030 3031 3032 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3026 class UpdateScraperLoggingConfigurationRequest < Struct.new( :scraper_id, :logging_destination, :scraper_components) SENSITIVE = [] include Aws::Structure end |
#scraper_id ⇒ String
The ID of the scraper whose logging configuration will be updated.
3026 3027 3028 3029 3030 3031 3032 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3026 class UpdateScraperLoggingConfigurationRequest < Struct.new( :scraper_id, :logging_destination, :scraper_components) SENSITIVE = [] include Aws::Structure end |