Class: Aws::PrometheusService::Types::UpdateScraperRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::UpdateScraperRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The new alias of the scraper.
-
#client_token ⇒ String
A unique identifier that you can provide to ensure the idempotency of the request.
-
#destination ⇒ Types::Destination
The new destination where the scraper sends metrics.
-
#exporters ⇒ Array<Types::ExporterConfiguration>
The exporter configurations for the scraper.
-
#role_configuration ⇒ Types::RoleConfiguration
Use this structure to enable cross-account access, so that you can use a target account to access Prometheus metrics from source accounts.
-
#scrape_configuration ⇒ Types::ScrapeConfiguration
Contains the base-64 encoded YAML configuration for the scraper.
-
#scraper_id ⇒ String
The ID of the scraper to update.
Instance Attribute Details
#alias ⇒ String
The new alias of the scraper.
3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3096 class UpdateScraperRequest < Struct.new( :scraper_id, :alias, :scrape_configuration, :destination, :role_configuration, :client_token, :exporters) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier that you can provide to ensure the idempotency of the request. Case-sensitive.
A suitable default value is auto-generated. You should normally not need to pass this option.
3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3096 class UpdateScraperRequest < Struct.new( :scraper_id, :alias, :scrape_configuration, :destination, :role_configuration, :client_token, :exporters) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The new destination where the scraper sends metrics. Valid destinations are Amazon Managed Service for Prometheus workspaces and CloudWatch datasets.
3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3096 class UpdateScraperRequest < Struct.new( :scraper_id, :alias, :scrape_configuration, :destination, :role_configuration, :client_token, :exporters) SENSITIVE = [] include Aws::Structure end |
#exporters ⇒ Array<Types::ExporterConfiguration>
The exporter configurations for the scraper. You can configure at most one Amazon OpenSearch Service domain. If you don't specify a value, the existing exporter configuration remains unchanged.
3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3096 class UpdateScraperRequest < Struct.new( :scraper_id, :alias, :scrape_configuration, :destination, :role_configuration, :client_token, :exporters) SENSITIVE = [] include Aws::Structure end |
#role_configuration ⇒ Types::RoleConfiguration
Use this structure to enable cross-account access, so that you can use a target account to access Prometheus metrics from source accounts.
3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3096 class UpdateScraperRequest < Struct.new( :scraper_id, :alias, :scrape_configuration, :destination, :role_configuration, :client_token, :exporters) SENSITIVE = [] include Aws::Structure end |
#scrape_configuration ⇒ Types::ScrapeConfiguration
Contains the base-64 encoded YAML configuration for the scraper.
3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3096 class UpdateScraperRequest < Struct.new( :scraper_id, :alias, :scrape_configuration, :destination, :role_configuration, :client_token, :exporters) SENSITIVE = [] include Aws::Structure end |
#scraper_id ⇒ String
The ID of the scraper to update.
3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3096 class UpdateScraperRequest < Struct.new( :scraper_id, :alias, :scrape_configuration, :destination, :role_configuration, :client_token, :exporters) SENSITIVE = [] include Aws::Structure end |