Class: Aws::PrometheusService::Types::UpdateScraperResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the updated scraper.

Returns:

  • (String)


3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3127

class UpdateScraperResponse < Struct.new(
  :scraper_id,
  :arn,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scraper_idString

The ID of the updated scraper.

Returns:

  • (String)


3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3127

class UpdateScraperResponse < Struct.new(
  :scraper_id,
  :arn,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::ScraperStatus

A structure that displays the current status of the scraper.



3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3127

class UpdateScraperResponse < Struct.new(
  :scraper_id,
  :arn,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The list of tag keys and values that are associated with the scraper.

Returns:

  • (Hash<String,String>)


3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3127

class UpdateScraperResponse < Struct.new(
  :scraper_id,
  :arn,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end