Class: Aws::PrometheusService::Types::UpdateWorkspaceAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::UpdateWorkspaceAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Represents the input of an UpdateWorkspaceAlias operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The new alias for the workspace.
-
#client_token ⇒ String
A unique identifier that you can provide to ensure the idempotency of the request.
-
#workspace_id ⇒ String
The ID of the workspace to update.
Instance Attribute Details
#alias ⇒ String
The new alias for the workspace. It does not need to be unique.
Amazon Managed Service for Prometheus will automatically strip any blank spaces from the beginning and end of the alias that you specify.
3160 3161 3162 3163 3164 3165 3166 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3160 class UpdateWorkspaceAliasRequest < Struct.new( :workspace_id, :alias, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier that you can provide to ensure the idempotency of the request. Case-sensitive.
A suitable default value is auto-generated. You should normally not need to pass this option.
3160 3161 3162 3163 3164 3165 3166 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3160 class UpdateWorkspaceAliasRequest < Struct.new( :workspace_id, :alias, :client_token) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace to update.
3160 3161 3162 3163 3164 3165 3166 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3160 class UpdateWorkspaceAliasRequest < Struct.new( :workspace_id, :alias, :client_token) SENSITIVE = [] include Aws::Structure end |