Class: Aws::PrometheusService::Types::UpdateWorkspaceConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::UpdateWorkspaceConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
You can include a token in your operation to make it an idempotent opeartion.
-
#limits_per_label_set ⇒ Array<Types::LimitsPerLabelSet>
This is an array of structures, where each structure defines a label set for the workspace, and defines the active time series limit for each of those label sets.
-
#out_of_order_time_window_in_seconds ⇒ Integer
Specifies the time window in seconds for accepting out of order samples.
-
#retention_period_in_days ⇒ Integer
Specifies how many days that metrics will be retained in the workspace.
-
#rule_query_offset_in_seconds ⇒ Integer
Specifies the duration in seconds to offset rule evaluation queries into the past.
-
#workspace_id ⇒ String
The ID of the workspace that you want to update.
Instance Attribute Details
#client_token ⇒ String
You can include a token in your operation to make it an idempotent opeartion.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3115 class UpdateWorkspaceConfigurationRequest < Struct.new( :workspace_id, :client_token, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#limits_per_label_set ⇒ Array<Types::LimitsPerLabelSet>
This is an array of structures, where each structure defines a label set for the workspace, and defines the active time series limit for each of those label sets. Each label name in a label set must be unique.
3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3115 class UpdateWorkspaceConfigurationRequest < Struct.new( :workspace_id, :client_token, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#out_of_order_time_window_in_seconds ⇒ Integer
Specifies the time window in seconds for accepting out of order samples. Out of order samples older than this window are rejected.
3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3115 class UpdateWorkspaceConfigurationRequest < Struct.new( :workspace_id, :client_token, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#retention_period_in_days ⇒ Integer
Specifies how many days that metrics will be retained in the workspace.
3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3115 class UpdateWorkspaceConfigurationRequest < Struct.new( :workspace_id, :client_token, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#rule_query_offset_in_seconds ⇒ Integer
Specifies the duration in seconds to offset rule evaluation queries into the past. This allows ingested samples to be available before rule evaluation.
3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3115 class UpdateWorkspaceConfigurationRequest < Struct.new( :workspace_id, :client_token, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace that you want to update. To find the IDs of your workspaces, use the [ListWorkspaces] operation.
[1]: docs.aws.amazon.com/prometheus/latest/APIReference/API_ListWorkspaces.htm
3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3115 class UpdateWorkspaceConfigurationRequest < Struct.new( :workspace_id, :client_token, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |