Class: Aws::PrometheusService::Types::VpcConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::VpcConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
The Amazon VPC configuration that specifies the network settings for a Prometheus collector to securely connect to Amazon MSK clusters. This configuration includes the security groups and subnets that control network access and placement for the collector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_ids ⇒ Array<String>
The security group IDs that control network access for the Prometheus collector.
-
#subnet_ids ⇒ Array<String>
The subnet IDs where the Prometheus collector will be deployed.
Instance Attribute Details
#security_group_ids ⇒ Array<String>
The security group IDs that control network access for the Prometheus collector. These security groups must allow the collector to communicate with your Amazon MSK cluster on the required ports.
3229 3230 3231 3232 3233 3234 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3229 class VpcConfiguration < Struct.new( :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The subnet IDs where the Prometheus collector will be deployed. The subnets must be in the same Amazon VPC as your Amazon MSK cluster and have network connectivity to the cluster.
3229 3230 3231 3232 3233 3234 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3229 class VpcConfiguration < Struct.new( :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |