Class: Aws::PrometheusService::Types::WorkspaceConfigurationDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::WorkspaceConfigurationDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
This structure contains the description of the workspace configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limits_per_label_set ⇒ Array<Types::LimitsPerLabelSet>
This is an array of structures, where each structure displays one label sets for the workspace and the limits for that label set.
-
#out_of_order_time_window_in_seconds ⇒ Integer
This field displays the out of order time window in seconds for accepting out of order samples.
-
#retention_period_in_days ⇒ Integer
This field displays how many days that metrics are retained in the workspace.
-
#rule_query_offset_in_seconds ⇒ Integer
This field displays the duration in seconds that rule evaluation queries are offset into the past.
-
#status ⇒ Types::WorkspaceConfigurationStatus
This structure displays the current status of the workspace configuration, and might also contain a reason for that status.
Instance Attribute Details
#limits_per_label_set ⇒ Array<Types::LimitsPerLabelSet>
This is an array of structures, where each structure displays one label sets for the workspace and the limits for that label set.
3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3266 class WorkspaceConfigurationDescription < Struct.new( :status, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#out_of_order_time_window_in_seconds ⇒ Integer
This field displays the out of order time window in seconds for accepting out of order samples.
3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3266 class WorkspaceConfigurationDescription < Struct.new( :status, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#retention_period_in_days ⇒ Integer
This field displays how many days that metrics are retained in the workspace.
3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3266 class WorkspaceConfigurationDescription < Struct.new( :status, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#rule_query_offset_in_seconds ⇒ Integer
This field displays the duration in seconds that rule evaluation queries are offset into the past.
3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3266 class WorkspaceConfigurationDescription < Struct.new( :status, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::WorkspaceConfigurationStatus
This structure displays the current status of the workspace configuration, and might also contain a reason for that status.
3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3266 class WorkspaceConfigurationDescription < Struct.new( :status, :limits_per_label_set, :retention_period_in_days, :out_of_order_time_window_in_seconds, :rule_query_offset_in_seconds) SENSITIVE = [] include Aws::Structure end |