Class: Aws::PrometheusService::Types::WorkspaceConfigurationStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

This structure displays the current status of the workspace configuration, and might also contain a reason for that status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#status_codeString

The current status of the workspace configuration.

Returns:

  • (String)


3289
3290
3291
3292
3293
3294
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3289

class WorkspaceConfigurationStatus < Struct.new(
  :status_code,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The reason for the current status, if a reason is available.

Returns:

  • (String)


3289
3290
3291
3292
3293
3294
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3289

class WorkspaceConfigurationStatus < Struct.new(
  :status_code,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end