Class: Aws::PrometheusService::Types::WorkspaceDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::WorkspaceDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
The full details about one Amazon Managed Service for Prometheus workspace in your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias that is assigned to this workspace to help identify it.
-
#arn ⇒ String
The ARN of the workspace.
-
#created_at ⇒ Time
The date and time that the workspace was created.
-
#kms_key_arn ⇒ String
(optional) If the workspace was created with a customer managed KMS key, the ARN for the key used.
-
#prometheus_endpoint ⇒ String
The Prometheus endpoint available for this workspace.
-
#status ⇒ Types::WorkspaceStatus
The current status of the workspace.
-
#tags ⇒ Hash<String,String>
The list of tag keys and values that are associated with the workspace.
-
#workspace_id ⇒ String
The unique ID for the workspace.
Instance Attribute Details
#alias ⇒ String
The alias that is assigned to this workspace to help identify it. It does not need to be unique.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the workspace. For example,
arn:aws:aps:<region>:123456789012:workspace/ws-example1-1234-abcd-5678-ef90abcd1234.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the workspace was created.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
(optional) If the workspace was created with a customer managed KMS key, the ARN for the key used.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#prometheus_endpoint ⇒ String
The Prometheus endpoint available for this workspace. For example,
https://aps-workspaces.<region>.amazonaws.com/workspaces/ws-example1-1234-abcd-5678-ef90abcd1234/api/v1/.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::WorkspaceStatus
The current status of the workspace.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of tag keys and values that are associated with the workspace.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The unique ID for the workspace. For example,
ws-example1-1234-abcd-5678-ef90abcd1234.
3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3407 class WorkspaceDescription < Struct.new( :workspace_id, :alias, :arn, :status, :prometheus_endpoint, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |