Class: Aws::PrometheusService::Types::WorkspaceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::WorkspaceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
The information about one Amazon Managed Service for Prometheus workspace in your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias that is assigned to this workspace to help identify it.
-
#arn ⇒ String
The ARN of the workspace.
-
#created_at ⇒ Time
The date and time that the workspace was created.
-
#kms_key_arn ⇒ String
(optional) If the workspace was created with a customer managed KMS key, the ARN for the key used.
-
#status ⇒ Types::WorkspaceStatus
The current status of the workspace.
-
#tags ⇒ Hash<String,String>
The list of tag keys and values that are associated with the workspace.
-
#workspace_id ⇒ String
The unique ID for the workspace.
Instance Attribute Details
#alias ⇒ String
The alias that is assigned to this workspace to help identify it. It does not need to be unique.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3402 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the workspace.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3402 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the workspace was created.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3402 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
(optional) If the workspace was created with a customer managed KMS key, the ARN for the key used.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3402 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::WorkspaceStatus
The current status of the workspace.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3402 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of tag keys and values that are associated with the workspace.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3402 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The unique ID for the workspace.
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3402 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |