Class: Aws::PrometheusService::Waiters::AnomalyDetectorActive

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-prometheusservice/waiters.rb,
sig/waiters.rbs

Overview

Wait until the anomaly detector reaches ACTIVE status

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ AnomalyDetectorActive

Returns a new instance of AnomalyDetectorActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 2
  • :before_attempt (Proc)
  • :before_wait (Proc)


90
91
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 90

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



128
129
130
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 128

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :workspace_id (required, String)

    The identifier of the workspace containing the anomaly detector.

  • :anomaly_detector_id (required, String)

    The identifier of the anomaly detector to describe.

Returns:



123
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 123

def wait: (