Class: Aws::PrometheusService::Waiters::AnomalyDetectorDeleted
- Inherits:
-
Object
- Object
- Aws::PrometheusService::Waiters::AnomalyDetectorDeleted
- Defined in:
- lib/aws-sdk-prometheusservice/waiters.rb,
sig/waiters.rbs
Overview
Wait until the anomaly detector reaches DELETED status
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AnomalyDetectorDeleted
constructor
A new instance of AnomalyDetectorDeleted.
-
#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AnomalyDetectorDeleted
Returns a new instance of AnomalyDetectorDeleted.
141 142 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 141
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
172 173 174 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 172 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Returns a response object which responds to the following methods:
- #anomaly_detector => Types::AnomalyDetectorDescription
167 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 167
def wait: (
|