Class: Aws::PrometheusService::Waiters::ScraperActive
- Inherits:
-
Object
- Object
- Aws::PrometheusService::Waiters::ScraperActive
- Defined in:
- lib/aws-sdk-prometheusservice/waiters.rb,
sig/waiters.rbs
Overview
Wait until a scraper reaches ACTIVE status
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ScraperActive
constructor
A new instance of ScraperActive.
-
#wait(params = {}) ⇒ Types::DescribeScraperResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ScraperActive
Returns a new instance of ScraperActive.
185 186 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 185
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
217 218 219 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 217 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeScraperResponse
Returns a response object which responds to the following methods:
- #scraper => Types::ScraperDescription
212 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 212
def wait: (
|