Class: Aws::PrometheusService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PrometheusService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-prometheusservice/client.rb
Overview
An API client for PrometheusService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PrometheusService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_alert_manager_definition(params = {}) ⇒ Types::CreateAlertManagerDefinitionResponse
The ‘CreateAlertManagerDefinition` operation creates the alert manager definition in a workspace.
-
#create_anomaly_detector(params = {}) ⇒ Types::CreateAnomalyDetectorResponse
Creates an anomaly detector within a workspace using the Random Cut Forest algorithm for time-series analysis.
-
#create_logging_configuration(params = {}) ⇒ Types::CreateLoggingConfigurationResponse
The ‘CreateLoggingConfiguration` operation creates rules and alerting logging configuration for the workspace.
-
#create_query_logging_configuration(params = {}) ⇒ Types::CreateQueryLoggingConfigurationResponse
Creates a query logging configuration for the specified workspace.
-
#create_rule_groups_namespace(params = {}) ⇒ Types::CreateRuleGroupsNamespaceResponse
The ‘CreateRuleGroupsNamespace` operation creates a rule groups namespace within a workspace.
-
#create_scraper(params = {}) ⇒ Types::CreateScraperResponse
The ‘CreateScraper` operation creates a scraper to collect metrics.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a Prometheus workspace.
-
#delete_alert_manager_definition(params = {}) ⇒ Struct
Deletes the alert manager definition from a workspace.
-
#delete_anomaly_detector(params = {}) ⇒ Struct
Removes an anomaly detector from a workspace.
-
#delete_logging_configuration(params = {}) ⇒ Struct
Deletes the rules and alerting logging configuration for a workspace.
-
#delete_query_logging_configuration(params = {}) ⇒ Struct
Deletes the query logging configuration for the specified workspace.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource-based policy attached to an Amazon Managed Service for Prometheus workspace.
-
#delete_rule_groups_namespace(params = {}) ⇒ Struct
Deletes one rule groups namespace and its associated rule groups definition.
-
#delete_scraper(params = {}) ⇒ Types::DeleteScraperResponse
The ‘DeleteScraper` operation deletes one scraper, and stops any metrics collection that the scraper performs.
-
#delete_scraper_logging_configuration(params = {}) ⇒ Struct
Deletes the logging configuration for a Amazon Managed Service for Prometheus scraper.
-
#delete_workspace(params = {}) ⇒ Struct
Deletes an existing workspace.
-
#describe_alert_manager_definition(params = {}) ⇒ Types::DescribeAlertManagerDefinitionResponse
Retrieves the full information about the alert manager definition for a workspace.
-
#describe_anomaly_detector(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Retrieves detailed information about a specific anomaly detector, including its status and configuration.
-
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns complete information about the current rules and alerting logging configuration of the workspace.
-
#describe_query_logging_configuration(params = {}) ⇒ Types::DescribeQueryLoggingConfigurationResponse
Retrieves the details of the query logging configuration for the specified workspace.
-
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Returns information about the resource-based policy attached to an Amazon Managed Service for Prometheus workspace.
-
#describe_rule_groups_namespace(params = {}) ⇒ Types::DescribeRuleGroupsNamespaceResponse
Returns complete information about one rule groups namespace.
-
#describe_scraper(params = {}) ⇒ Types::DescribeScraperResponse
The ‘DescribeScraper` operation displays information about an existing scraper.
-
#describe_scraper_logging_configuration(params = {}) ⇒ Types::DescribeScraperLoggingConfigurationResponse
Describes the logging configuration for a Amazon Managed Service for Prometheus scraper.
-
#describe_workspace(params = {}) ⇒ Types::DescribeWorkspaceResponse
Returns information about an existing workspace.
-
#describe_workspace_configuration(params = {}) ⇒ Types::DescribeWorkspaceConfigurationResponse
Use this operation to return information about the configuration of a workspace.
-
#get_default_scraper_configuration(params = {}) ⇒ Types::GetDefaultScraperConfigurationResponse
The ‘GetDefaultScraperConfiguration` operation returns the default scraper configuration used when Amazon EKS creates a scraper for you.
-
#list_anomaly_detectors(params = {}) ⇒ Types::ListAnomalyDetectorsResponse
Returns a paginated list of anomaly detectors for a workspace with optional filtering by alias.
-
#list_rule_groups_namespaces(params = {}) ⇒ Types::ListRuleGroupsNamespacesResponse
Returns a list of rule groups namespaces in a workspace.
-
#list_scrapers(params = {}) ⇒ Types::ListScrapersResponse
The ‘ListScrapers` operation lists all of the scrapers in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
The ‘ListTagsForResource` operation returns the tags that are associated with an Amazon Managed Service for Prometheus resource.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Lists all of the Amazon Managed Service for Prometheus workspaces in your account.
-
#put_alert_manager_definition(params = {}) ⇒ Types::PutAlertManagerDefinitionResponse
Updates an existing alert manager definition in a workspace.
-
#put_anomaly_detector(params = {}) ⇒ Types::PutAnomalyDetectorResponse
When you call ‘PutAnomalyDetector`, the operation creates a new anomaly detector if one doesn’t exist, or updates an existing one.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource-based policy for an Amazon Managed Service for Prometheus workspace.
-
#put_rule_groups_namespace(params = {}) ⇒ Types::PutRuleGroupsNamespaceResponse
Updates an existing rule groups namespace within a workspace.
-
#tag_resource(params = {}) ⇒ Struct
The ‘TagResource` operation associates tags with an Amazon Managed Service for Prometheus resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from an Amazon Managed Service for Prometheus resource.
-
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Updates the log group ARN or the workspace ID of the current rules and alerting logging configuration.
-
#update_query_logging_configuration(params = {}) ⇒ Types::UpdateQueryLoggingConfigurationResponse
Updates the query logging configuration for the specified workspace.
-
#update_scraper(params = {}) ⇒ Types::UpdateScraperResponse
Updates an existing scraper.
-
#update_scraper_logging_configuration(params = {}) ⇒ Types::UpdateScraperLoggingConfigurationResponse
Updates the logging configuration for a Amazon Managed Service for Prometheus scraper.
-
#update_workspace_alias(params = {}) ⇒ Struct
Updates the alias of an existing workspace.
-
#update_workspace_configuration(params = {}) ⇒ Types::UpdateWorkspaceConfigurationResponse
Use this operation to create or update the label sets, label set limits, and retention period of a workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3222 3223 3224 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 3222 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3225 3226 3227 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 3225 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 3072 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PrometheusService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-prometheusservice' context[:gem_version] = '1.71.0' Seahorse::Client::Request.new(handlers, context) end |
#create_alert_manager_definition(params = {}) ⇒ Types::CreateAlertManagerDefinitionResponse
The ‘CreateAlertManagerDefinition` operation creates the alert manager definition in a workspace. If a workspace already has an alert manager definition, don’t use this operation to update it. Instead, use ‘PutAlertManagerDefinition`.
526 527 528 529 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 526 def create_alert_manager_definition(params = {}, = {}) req = build_request(:create_alert_manager_definition, params) req.send_request() end |
#create_anomaly_detector(params = {}) ⇒ Types::CreateAnomalyDetectorResponse
Creates an anomaly detector within a workspace using the Random Cut Forest algorithm for time-series analysis. The anomaly detector analyzes Amazon Managed Service for Prometheus metrics to identify unusual patterns and behaviors.
622 623 624 625 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 622 def create_anomaly_detector(params = {}, = {}) req = build_request(:create_anomaly_detector, params) req.send_request() end |
#create_logging_configuration(params = {}) ⇒ Types::CreateLoggingConfigurationResponse
The ‘CreateLoggingConfiguration` operation creates rules and alerting logging configuration for the workspace. Use this operation to set the CloudWatch log group to which the logs will be published to.
<note markdown=“1”> These logging configurations are only for rules and alerting logs.
</note>
671 672 673 674 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 671 def create_logging_configuration(params = {}, = {}) req = build_request(:create_logging_configuration, params) req.send_request() end |
#create_query_logging_configuration(params = {}) ⇒ Types::CreateQueryLoggingConfigurationResponse
Creates a query logging configuration for the specified workspace. This operation enables logging of queries that exceed the specified QSP threshold.
725 726 727 728 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 725 def create_query_logging_configuration(params = {}, = {}) req = build_request(:create_query_logging_configuration, params) req.send_request() end |
#create_rule_groups_namespace(params = {}) ⇒ Types::CreateRuleGroupsNamespaceResponse
The ‘CreateRuleGroupsNamespace` operation creates a rule groups namespace within a workspace. A rule groups namespace is associated with exactly one rules file. A workspace can have multiple rule groups namespaces.
The combined length of a rule group namespace and a rule group name cannot exceed 721 UTF-8 bytes.
Use this operation only to create new rule groups namespaces. To update an existing rule groups namespace, use ‘PutRuleGroupsNamespace`.
803 804 805 806 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 803 def create_rule_groups_namespace(params = {}, = {}) req = build_request(:create_rule_groups_namespace, params) req.send_request() end |
#create_scraper(params = {}) ⇒ Types::CreateScraperResponse
The ‘CreateScraper` operation creates a scraper to collect metrics. A scraper pulls metrics from Prometheus-compatible sources and sends them to your Amazon Managed Service for Prometheus workspace. You can configure scrapers to collect metrics from Amazon EKS clusters, Amazon MSK clusters, or from VPC-based sources that support DNS-based service discovery. Scrapers are flexible, and can be configured to control what metrics are collected, the frequency of collection, what transformations are applied to the metrics, and more.
An IAM role will be created for you that Amazon Managed Service for Prometheus uses to access the metrics in your source. You must configure this role with a policy that allows it to scrape metrics from your source. For Amazon EKS sources, see [Configuring your Amazon EKS cluster] in the *Amazon Managed Service for Prometheus User Guide*.
The ‘scrapeConfiguration` parameter contains the base-64 encoded YAML configuration for the scraper.
When creating a scraper, the service creates a ‘Network Interface` in each **Availability Zone** that are passed into `CreateScraper` through subnets. These network interfaces are used to connect to your source within the VPC for scraping metrics.
<note markdown=“1”> For more information about collectors, including what metrics are collected, and how to configure the scraper, see [Using an Amazon Web Services managed collector] in the *Amazon Managed Service for Prometheus User Guide*.
</note>
[1]: docs.aws.amazon.com/prometheus/latest/userguide/AMP-collector-how-to.html#AMP-collector-eks-setup [2]: docs.aws.amazon.com/prometheus/latest/userguide/AMP-collector-how-to.html
1014 1015 1016 1017 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1014 def create_scraper(params = {}, = {}) req = build_request(:create_scraper, params) req.send_request() end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a Prometheus workspace. A workspace is a logical space dedicated to the storage and querying of Prometheus metrics. You can have one or more workspaces in each Region in your account.
1082 1083 1084 1085 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1082 def create_workspace(params = {}, = {}) req = build_request(:create_workspace, params) req.send_request() end |
#delete_alert_manager_definition(params = {}) ⇒ Struct
Deletes the alert manager definition from a workspace.
1112 1113 1114 1115 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1112 def delete_alert_manager_definition(params = {}, = {}) req = build_request(:delete_alert_manager_definition, params) req.send_request() end |
#delete_anomaly_detector(params = {}) ⇒ Struct
Removes an anomaly detector from a workspace. This operation is idempotent.
1148 1149 1150 1151 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1148 def delete_anomaly_detector(params = {}, = {}) req = build_request(:delete_anomaly_detector, params) req.send_request() end |
#delete_logging_configuration(params = {}) ⇒ Struct
Deletes the rules and alerting logging configuration for a workspace.
<note markdown=“1”> These logging configurations are only for rules and alerting logs.
</note>
1183 1184 1185 1186 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1183 def delete_logging_configuration(params = {}, = {}) req = build_request(:delete_logging_configuration, params) req.send_request() end |
#delete_query_logging_configuration(params = {}) ⇒ Struct
Deletes the query logging configuration for the specified workspace.
1214 1215 1216 1217 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1214 def delete_query_logging_configuration(params = {}, = {}) req = build_request(:delete_query_logging_configuration, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource-based policy attached to an Amazon Managed Service for Prometheus workspace.
1251 1252 1253 1254 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1251 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_rule_groups_namespace(params = {}) ⇒ Struct
Deletes one rule groups namespace and its associated rule groups definition.
1287 1288 1289 1290 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1287 def delete_rule_groups_namespace(params = {}, = {}) req = build_request(:delete_rule_groups_namespace, params) req.send_request() end |
#delete_scraper(params = {}) ⇒ Types::DeleteScraperResponse
The ‘DeleteScraper` operation deletes one scraper, and stops any metrics collection that the scraper performs.
1342 1343 1344 1345 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1342 def delete_scraper(params = {}, = {}) req = build_request(:delete_scraper, params) req.send_request() end |
#delete_scraper_logging_configuration(params = {}) ⇒ Struct
Deletes the logging configuration for a Amazon Managed Service for Prometheus scraper.
1373 1374 1375 1376 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1373 def delete_scraper_logging_configuration(params = {}, = {}) req = build_request(:delete_scraper_logging_configuration, params) req.send_request() end |
#delete_workspace(params = {}) ⇒ Struct
Deletes an existing workspace.
<note markdown=“1”> When you delete a workspace, the data that has been ingested into it is not immediately deleted. It will be permanently deleted within one month.
</note>
1409 1410 1411 1412 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1409 def delete_workspace(params = {}, = {}) req = build_request(:delete_workspace, params) req.send_request() end |
#describe_alert_manager_definition(params = {}) ⇒ Types::DescribeAlertManagerDefinitionResponse
Retrieves the full information about the alert manager definition for a workspace.
1442 1443 1444 1445 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1442 def describe_alert_manager_definition(params = {}, = {}) req = build_request(:describe_alert_manager_definition, params) req.send_request() end |
#describe_anomaly_detector(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Retrieves detailed information about a specific anomaly detector, including its status and configuration.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* anomaly_detector_active
* anomaly_detector_deleted
1501 1502 1503 1504 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1501 def describe_anomaly_detector(params = {}, = {}) req = build_request(:describe_anomaly_detector, params) req.send_request() end |
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns complete information about the current rules and alerting logging configuration of the workspace.
<note markdown=“1”> These logging configurations are only for rules and alerting logs.
</note>
1539 1540 1541 1542 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1539 def describe_logging_configuration(params = {}, = {}) req = build_request(:describe_logging_configuration, params) req.send_request() end |
#describe_query_logging_configuration(params = {}) ⇒ Types::DescribeQueryLoggingConfigurationResponse
Retrieves the details of the query logging configuration for the specified workspace.
1576 1577 1578 1579 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1576 def describe_query_logging_configuration(params = {}, = {}) req = build_request(:describe_query_logging_configuration, params) req.send_request() end |
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Returns information about the resource-based policy attached to an Amazon Managed Service for Prometheus workspace.
1609 1610 1611 1612 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1609 def describe_resource_policy(params = {}, = {}) req = build_request(:describe_resource_policy, params) req.send_request() end |
#describe_rule_groups_namespace(params = {}) ⇒ Types::DescribeRuleGroupsNamespaceResponse
Returns complete information about one rule groups namespace. To retrieve a list of rule groups namespaces, use ‘ListRuleGroupsNamespaces`.
1651 1652 1653 1654 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1651 def describe_rule_groups_namespace(params = {}, = {}) req = build_request(:describe_rule_groups_namespace, params) req.send_request() end |
#describe_scraper(params = {}) ⇒ Types::DescribeScraperResponse
The ‘DescribeScraper` operation displays information about an existing scraper.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* scraper_active
* scraper_deleted
1752 1753 1754 1755 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1752 def describe_scraper(params = {}, = {}) req = build_request(:describe_scraper, params) req.send_request() end |
#describe_scraper_logging_configuration(params = {}) ⇒ Types::DescribeScraperLoggingConfigurationResponse
Describes the logging configuration for a Amazon Managed Service for Prometheus scraper.
1793 1794 1795 1796 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1793 def describe_scraper_logging_configuration(params = {}, = {}) req = build_request(:describe_scraper_logging_configuration, params) req.send_request() end |
#describe_workspace(params = {}) ⇒ Types::DescribeWorkspaceResponse
Returns information about an existing workspace.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* workspace_active
* workspace_deleted
1835 1836 1837 1838 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1835 def describe_workspace(params = {}, = {}) req = build_request(:describe_workspace, params) req.send_request() end |
#describe_workspace_configuration(params = {}) ⇒ Types::DescribeWorkspaceConfigurationResponse
Use this operation to return information about the configuration of a workspace. The configuration details returned include workspace configuration status, label set limits, and retention period.
1877 1878 1879 1880 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1877 def describe_workspace_configuration(params = {}, = {}) req = build_request(:describe_workspace_configuration, params) req.send_request() end |
#get_default_scraper_configuration(params = {}) ⇒ Types::GetDefaultScraperConfigurationResponse
The ‘GetDefaultScraperConfiguration` operation returns the default scraper configuration used when Amazon EKS creates a scraper for you.
1908 1909 1910 1911 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1908 def get_default_scraper_configuration(params = {}, = {}) req = build_request(:get_default_scraper_configuration, params) req.send_request() end |
#list_anomaly_detectors(params = {}) ⇒ Types::ListAnomalyDetectorsResponse
Returns a paginated list of anomaly detectors for a workspace with optional filtering by alias.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1964 1965 1966 1967 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 1964 def list_anomaly_detectors(params = {}, = {}) req = build_request(:list_anomaly_detectors, params) req.send_request() end |
#list_rule_groups_namespaces(params = {}) ⇒ Types::ListRuleGroupsNamespacesResponse
Returns a list of rule groups namespaces in a workspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2025 2026 2027 2028 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2025 def list_rule_groups_namespaces(params = {}, = {}) req = build_request(:list_rule_groups_namespaces, params) req.send_request() end |
#list_scrapers(params = {}) ⇒ Types::ListScrapersResponse
The ‘ListScrapers` operation lists all of the scrapers in your account. This includes scrapers being created or deleted. You can optionally filter the returned list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2237 2238 2239 2240 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2237 def list_scrapers(params = {}, = {}) req = build_request(:list_scrapers, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
The ‘ListTagsForResource` operation returns the tags that are associated with an Amazon Managed Service for Prometheus resource. Currently, the only resources that can be tagged are scrapers, workspaces, and rule groups namespaces.
2270 2271 2272 2273 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2270 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Lists all of the Amazon Managed Service for Prometheus workspaces in your account. This includes workspaces being created or deleted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2331 2332 2333 2334 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2331 def list_workspaces(params = {}, = {}) req = build_request(:list_workspaces, params) req.send_request() end |
#put_alert_manager_definition(params = {}) ⇒ Types::PutAlertManagerDefinitionResponse
Updates an existing alert manager definition in a workspace. If the workspace does not already have an alert manager definition, don’t use this operation to create it. Instead, use ‘CreateAlertManagerDefinition`.
2383 2384 2385 2386 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2383 def put_alert_manager_definition(params = {}, = {}) req = build_request(:put_alert_manager_definition, params) req.send_request() end |
#put_anomaly_detector(params = {}) ⇒ Types::PutAnomalyDetectorResponse
When you call ‘PutAnomalyDetector`, the operation creates a new anomaly detector if one doesn’t exist, or updates an existing one. Each call to this operation triggers a complete retraining of the detector, which includes querying the minimum required samples and backfilling the detector with historical data. This process occurs regardless of whether you’re making a minor change like updating the evaluation interval or making more substantial modifications. The operation serves as the single method for creating, updating, and retraining anomaly detectors.
2477 2478 2479 2480 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2477 def put_anomaly_detector(params = {}, = {}) req = build_request(:put_anomaly_detector, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource-based policy for an Amazon Managed Service for Prometheus workspace. Use resource-based policies to grant permissions to other AWS accounts or services to access your workspace.
Only Prometheus-compatible APIs can be used for workspace sharing. You can add non-Prometheus-compatible APIs to the policy, but they will be ignored. For more information, see [Prometheus-compatible APIs] in the *Amazon Managed Service for Prometheus User Guide*.
If your workspace uses customer-managed KMS keys for encryption, you must grant the principals in your resource-based policy access to those KMS keys. You can do this by creating KMS grants. For more information, see [CreateGrant] in the *AWS Key Management Service API Reference* and [Encryption at rest] in the *Amazon Managed Service for Prometheus User Guide*.
For more information about working with IAM, see [Using Amazon Managed Service for Prometheus with IAM] in the *Amazon Managed Service for Prometheus User Guide*.
[1]: docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference-Prometheus-Compatible-Apis.html [2]: docs.aws.amazon.com/kms/latest/APIReference/API_CreateGrant.html [3]: docs.aws.amazon.com/prometheus/latest/userguide/encryption-at-rest-Amazon-Service-Prometheus.html [4]: docs.aws.amazon.com/prometheus/latest/userguide/security_iam_service-with-iam.html
2558 2559 2560 2561 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2558 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#put_rule_groups_namespace(params = {}) ⇒ Types::PutRuleGroupsNamespaceResponse
Updates an existing rule groups namespace within a workspace. A rule groups namespace is associated with exactly one rules file. A workspace can have multiple rule groups namespaces.
The combined length of a rule group namespace and a rule group name cannot exceed 721 UTF-8 bytes.
Use this operation only to update existing rule groups namespaces. To create a new rule groups namespace, use ‘CreateRuleGroupsNamespace`.
You can’t use this operation to add tags to an existing rule groups namespace. Instead, use ‘TagResource`.
2630 2631 2632 2633 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2630 def put_rule_groups_namespace(params = {}, = {}) req = build_request(:put_rule_groups_namespace, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
The ‘TagResource` operation associates tags with an Amazon Managed Service for Prometheus resource. The only resources that can be tagged are rule groups namespaces, scrapers, and workspaces.
If you specify a new tag key for the resource, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag. To remove a tag, use ‘UntagResource`.
2668 2669 2670 2671 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2668 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from an Amazon Managed Service for Prometheus resource. The only resources that can be tagged are rule groups namespaces, scrapers, and workspaces.
2696 2697 2698 2699 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2696 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Updates the log group ARN or the workspace ID of the current rules and alerting logging configuration.
<note markdown=“1”> These logging configurations are only for rules and alerting logs.
</note>
2743 2744 2745 2746 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2743 def update_logging_configuration(params = {}, = {}) req = build_request(:update_logging_configuration, params) req.send_request() end |
#update_query_logging_configuration(params = {}) ⇒ Types::UpdateQueryLoggingConfigurationResponse
Updates the query logging configuration for the specified workspace.
2795 2796 2797 2798 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2795 def update_query_logging_configuration(params = {}, = {}) req = build_request(:update_query_logging_configuration, params) req.send_request() end |
#update_scraper(params = {}) ⇒ Types::UpdateScraperResponse
Updates an existing scraper.
You can’t use this function to update the source from which the scraper is collecting metrics. To change the source, delete the scraper and create a new one.
2908 2909 2910 2911 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2908 def update_scraper(params = {}, = {}) req = build_request(:update_scraper, params) req.send_request() end |
#update_scraper_logging_configuration(params = {}) ⇒ Types::UpdateScraperLoggingConfigurationResponse
Updates the logging configuration for a Amazon Managed Service for Prometheus scraper.
2959 2960 2961 2962 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2959 def update_scraper_logging_configuration(params = {}, = {}) req = build_request(:update_scraper_logging_configuration, params) req.send_request() end |
#update_workspace_alias(params = {}) ⇒ Struct
Updates the alias of an existing workspace.
2996 2997 2998 2999 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 2996 def update_workspace_alias(params = {}, = {}) req = build_request(:update_workspace_alias, params) req.send_request() end |
#update_workspace_configuration(params = {}) ⇒ Types::UpdateWorkspaceConfigurationResponse
Use this operation to create or update the label sets, label set limits, and retention period of a workspace.
You must specify at least one of ‘limitsPerLabelSet` or `retentionPeriodInDays` for the request to be valid.
3063 3064 3065 3066 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 3063 def update_workspace_configuration(params = {}, = {}) req = build_request(:update_workspace_configuration, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ———————— | ———————————- | ——– | ————- | | anomaly_detector_active | #describe_anomaly_detector | 2 | 60 | | anomaly_detector_deleted | #describe_anomaly_detector | 2 | 60 | | scraper_active | #describe_scraper | 2 | 60 | | scraper_deleted | #describe_scraper | 2 | 60 | | workspace_active | #describe_workspace | 2 | 60 | | workspace_deleted | #describe_workspace | 2 | 60 |
3183 3184 3185 3186 3187 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 3183 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3191 3192 3193 |
# File 'lib/aws-sdk-prometheusservice/client.rb', line 3191 def waiter_names waiters.keys end |