Class: Aws::PrometheusService::Types::ExporterConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::ExporterConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
Note:
ExporterConfiguration is a union - when making an API calls you must set exactly one of the members.
Note:
ExporterConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ExporterConfiguration corresponding to the set member.
Contains the configuration for an exporter managed by the scraper.
Defined Under Namespace
Classes: OpenSearchConfiguration, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#open_search_configuration ⇒ Types::OpenSearchExporterConfiguration
The configuration that the scraper uses to export metrics to an Amazon OpenSearch Service domain.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#open_search_configuration ⇒ Types::OpenSearchExporterConfiguration
The configuration that the scraper uses to export metrics to an Amazon OpenSearch Service domain.
1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1450 class ExporterConfiguration < Struct.new( :open_search_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchConfiguration < ExporterConfiguration; end class Unknown < ExporterConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1450 1451 1452 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 1450 def unknown @unknown end |