Class: Aws::PrometheusService::Types::ScraperDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::ScraperDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
The ScraperDescription structure contains the full details about one
scraper in your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
(Optional) A name associated with the scraper.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the scraper.
-
#created_at ⇒ Time
The date and time that the scraper was created.
-
#destination ⇒ Types::Destination
The destination where the scraper sends metrics.
-
#last_modified_at ⇒ Time
The date and time that the scraper was last modified.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the scraper to discover and collect metrics on your behalf.
-
#role_configuration ⇒ Types::RoleConfiguration
This structure displays information about the IAM roles used for cross-account scraping configuration.
-
#scrape_configuration ⇒ Types::ScrapeConfiguration
The configuration in use by the scraper.
-
#scraper_id ⇒ String
The ID of the scraper.
-
#source ⇒ Types::Source
The Amazon EKS cluster from which the scraper collects metrics.
-
#status ⇒ Types::ScraperStatus
A structure that contains the current status of the scraper.
-
#status_reason ⇒ String
If there is a failure, the reason for the failure.
-
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values associated with the scraper.
Instance Attribute Details
#alias ⇒ String
(Optional) A name associated with the scraper.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the scraper. For example,
arn:aws:aps:<region>:123456798012:scraper/s-example1-1234-abcd-5678-ef9012abcd34.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the scraper was created.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The destination where the scraper sends metrics. Valid destinations are Amazon Managed Service for Prometheus workspaces and CloudWatch datasets.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_at ⇒ Time
The date and time that the scraper was last modified.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the scraper to discover and collect metrics on your behalf.
For example,
arn:aws:iam::123456789012:role/service-role/AmazonGrafanaServiceRole-12example.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#role_configuration ⇒ Types::RoleConfiguration
This structure displays information about the IAM roles used for cross-account scraping configuration.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#scrape_configuration ⇒ Types::ScrapeConfiguration
The configuration in use by the scraper.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#scraper_id ⇒ String
The ID of the scraper. For example,
s-example1-1234-abcd-5678-ef9012abcd34.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::Source
The Amazon EKS cluster from which the scraper collects metrics.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ScraperStatus
A structure that contains the current status of the scraper.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
If there is a failure, the reason for the failure.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
(Optional) The list of tag keys and values associated with the scraper.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2575 class ScraperDescription < Struct.new( :alias, :scraper_id, :arn, :role_arn, :status, :created_at, :last_modified_at, :tags, :status_reason, :scrape_configuration, :source, :destination, :role_configuration) SENSITIVE = [] include Aws::Structure end |