Class: Aws::PrometheusService::Types::Source

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Note:

Source is a union - when making an API calls you must set exactly one of the members.

Note:

Source is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Source corresponding to the set member.

The source of collected metrics for a scraper.

Defined Under Namespace

Classes: EksConfiguration, Unknown, VpcConfiguration

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eks_configurationTypes::EksConfiguration

The Amazon EKS cluster from which a scraper collects metrics.



2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2781

class Source < Struct.new(
  :eks_configuration,
  :vpc_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EksConfiguration < Source; end
  class VpcConfiguration < Source; end
  class Unknown < Source; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2781
2782
2783
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2781

def unknown
  @unknown
end

#vpc_configurationTypes::VpcConfiguration

The Amazon VPC configuration for the Prometheus collector when connecting to Amazon MSK clusters. This configuration enables secure, private network connectivity between the collector and your Amazon MSK cluster within your Amazon VPC.



2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-prometheusservice/types.rb', line 2781

class Source < Struct.new(
  :eks_configuration,
  :vpc_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EksConfiguration < Source; end
  class VpcConfiguration < Source; end
  class Unknown < Source; end
end