Class: Aws::PrometheusService::Types::UpdateWorkspaceAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-prometheusservice/types.rb

Overview

Represents the input of an UpdateWorkspaceAlias operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

The new alias for the workspace. It does not need to be unique.

Amazon Managed Service for Prometheus will automatically strip any blank spaces from the beginning and end of the alias that you specify.

Returns:

  • (String)


3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3092

class UpdateWorkspaceAliasRequest < Struct.new(
  :workspace_id,
  :alias,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique identifier that you can provide to ensure the idempotency of the request. Case-sensitive.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3092

class UpdateWorkspaceAliasRequest < Struct.new(
  :workspace_id,
  :alias,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace to update.

Returns:

  • (String)


3092
3093
3094
3095
3096
3097
3098
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3092

class UpdateWorkspaceAliasRequest < Struct.new(
  :workspace_id,
  :alias,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end