Class: Aws::PrometheusService::Types::WorkspaceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PrometheusService::Types::WorkspaceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-prometheusservice/types.rb
Overview
The information about one Amazon Managed Service for Prometheus workspace in your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias that is assigned to this workspace to help identify it.
-
#arn ⇒ String
The ARN of the workspace.
-
#created_at ⇒ Time
The date and time that the workspace was created.
-
#kms_key_arn ⇒ String
(optional) If the workspace was created with a customer managed KMS key, the ARN for the key used.
-
#status ⇒ Types::WorkspaceStatus
The current status of the workspace.
-
#tags ⇒ Hash<String,String>
The list of tag keys and values that are associated with the workspace.
-
#workspace_id ⇒ String
The unique ID for the workspace.
Instance Attribute Details
#alias ⇒ String
The alias that is assigned to this workspace to help identify it. It does not need to be unique.
3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3375 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the workspace.
3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3375 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the workspace was created.
3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3375 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
(optional) If the workspace was created with a customer managed KMS key, the ARN for the key used.
3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3375 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::WorkspaceStatus
The current status of the workspace.
3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3375 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of tag keys and values that are associated with the workspace.
3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3375 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The unique ID for the workspace.
3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 |
# File 'lib/aws-sdk-prometheusservice/types.rb', line 3375 class WorkspaceSummary < Struct.new( :workspace_id, :alias, :arn, :status, :created_at, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |