Class: Aws::PrometheusService::Waiters::AnomalyDetectorActive
- Inherits:
-
Object
- Object
- Aws::PrometheusService::Waiters::AnomalyDetectorActive
- Defined in:
- lib/aws-sdk-prometheusservice/waiters.rb,
sig/waiters.rbs
Overview
Wait until the anomaly detector reaches ACTIVE status
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AnomalyDetectorActive
constructor
A new instance of AnomalyDetectorActive.
-
#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AnomalyDetectorActive
Returns a new instance of AnomalyDetectorActive.
90 91 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 90
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
128 129 130 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 128 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Returns a response object which responds to the following methods:
- #anomaly_detector => Types::AnomalyDetectorDescription
123 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 123
def wait: (
|