Class: Aws::PrometheusService::Waiters::AnomalyDetectorActive

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-prometheusservice/waiters.rb

Overview

Wait until the anomaly detector reaches ACTIVE status

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ AnomalyDetectorActive

Returns a new instance of AnomalyDetectorActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 2
  • :before_attempt (Proc)
  • :before_wait (Proc)


90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 90

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 60,
    delay: 2,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_anomaly_detector,
      acceptors: [
        {
          "matcher" => "path",
          "argument" => "anomaly_detector.status.status_code",
          "state" => "success",
          "expected" => "ACTIVE"
        },
        {
          "matcher" => "path",
          "argument" => "anomaly_detector.status.status_code",
          "state" => "retry",
          "expected" => "CREATING"
        },
        {
          "matcher" => "path",
          "argument" => "anomaly_detector.status.status_code",
          "state" => "retry",
          "expected" => "UPDATING"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



128
129
130
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 128

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :workspace_id (required, String)

    The identifier of the workspace containing the anomaly detector.

  • :anomaly_detector_id (required, String)

    The identifier of the anomaly detector to describe.

Returns:



123
124
125
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 123

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end