Class: Aws::PrometheusService::Waiters::AnomalyDetectorActive
- Inherits:
-
Object
- Object
- Aws::PrometheusService::Waiters::AnomalyDetectorActive
- Defined in:
- lib/aws-sdk-prometheusservice/waiters.rb
Overview
Wait until the anomaly detector reaches ACTIVE status
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AnomalyDetectorActive
constructor
A new instance of AnomalyDetectorActive.
-
#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AnomalyDetectorActive
Returns a new instance of AnomalyDetectorActive.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 90 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 60, delay: 2, poller: Aws::Waiters::Poller.new( operation_name: :describe_anomaly_detector, acceptors: [ { "matcher" => "path", "argument" => "anomaly_detector.status.status_code", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "anomaly_detector.status.status_code", "state" => "retry", "expected" => "CREATING" }, { "matcher" => "path", "argument" => "anomaly_detector.status.status_code", "state" => "retry", "expected" => "UPDATING" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
128 129 130 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 128 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Returns a response object which responds to the following methods:
-
#anomaly_detector => Types::AnomalyDetectorDescription
123 124 125 |
# File 'lib/aws-sdk-prometheusservice/waiters.rb', line 123 def wait(params = {}) @waiter.wait(client: @client, params: params) end |